package com.os.ems.base.domain;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.os.common.core.domain.entity.SysDept;
import com.os.common.core.domain.entity.SysMenu;

import java.io.Serializable;
import java.util.List;
import java.util.stream.Collectors;

/**
 * Treeselect树结构实体类
 *
 * @author ruoyi
 */
public class TreeSelects implements Serializable
{
    private static final long serialVersionUID = 1L;

    /** 节点ID */
    private Long id;

    /** 节点名称 */
    private String label;

    private String code;

    /** 子节点 */
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<TreeSelects> children;

    public TreeSelects()
    {

    }

    public TreeSelects(SysDept dept)
    {
        this.id = dept.getDeptId();
        this.label = dept.getDeptName();
        this.children = dept.getChildren().stream().map(TreeSelects::new).collect(Collectors.toList());
    }

    public TreeSelects(EmsBaseMonitorInfo baseMonitorInfo){
        this.id = baseMonitorInfo.getObjId();
        this.label = baseMonitorInfo.getMonitorName();
        this.code = baseMonitorInfo.getMonitorCode();
        this.children = baseMonitorInfo.getChildren().stream().map(TreeSelects::new).collect(Collectors.toList());
    }

    public TreeSelects(EmsBaseWorkUnit baseWorkUnit){
        this.id = baseWorkUnit.getObjId();
        this.label = baseWorkUnit.getWorkUnitName();
        this.code = baseWorkUnit.getWorkUnitCode();
        this.children = baseWorkUnit.getChildren().stream().map(TreeSelects::new).collect(Collectors.toList());
    }

    public TreeSelects(SysMenu menu)
    {
        this.id = menu.getMenuId();
        this.label = menu.getMenuName();
        this.children = menu.getChildren().stream().map(TreeSelects::new).collect(Collectors.toList());
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Long getId()
    {
        return id;
    }

    public void setId(Long id)
    {
        this.id = id;
    }

    public String getLabel()
    {
        return label;
    }

    public void setLabel(String label)
    {
        this.label = label;
    }

    public List<TreeSelects> getChildren()
    {
        return children;
    }

    public void setChildren(List<TreeSelects> children)
    {
        this.children = children;
    }
}
