package com.os.ems.record.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.ems.record.mapper.EmsRecordSteamInstantMapper;
import com.os.ems.record.domain.EmsRecordSteamInstant;
import com.os.ems.record.service.IEmsRecordSteamInstantService;

/**
 * 蒸汽历史数据Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-22
 */
@Service
public class EmsRecordSteamInstantServiceImpl implements IEmsRecordSteamInstantService {
    @Autowired
    private EmsRecordSteamInstantMapper emsRecordSteamInstantMapper;

    /**
     * 查询蒸汽历史数据
     *
     * @param objId 蒸汽历史数据主键
     * @return 蒸汽历史数据
     */
    @Override
    public EmsRecordSteamInstant selectEmsRecordSteamInstantByObjId(Long objId) {
        return emsRecordSteamInstantMapper.selectEmsRecordSteamInstantByObjId(objId);
    }

    /**
     * 查询蒸汽历史数据列表
     *
     * @param emsRecordSteamInstant 蒸汽历史数据
     * @return 蒸汽历史数据
     */
    @Override
    public List<EmsRecordSteamInstant> selectEmsRecordSteamInstantList(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.selectEmsRecordSteamInstantList(emsRecordSteamInstant);
    }

    /**
     * 新增蒸汽历史数据
     *
     * @param emsRecordSteamInstant 蒸汽历史数据
     * @return 结果
     */
    @Override
    public int insertEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.insertEmsRecordSteamInstant(emsRecordSteamInstant);
    }

    /**
     * 修改蒸汽历史数据
     *
     * @param emsRecordSteamInstant 蒸汽历史数据
     * @return 结果
     */
    @Override
    public int updateEmsRecordSteamInstant(EmsRecordSteamInstant emsRecordSteamInstant) {
        return emsRecordSteamInstantMapper.updateEmsRecordSteamInstant(emsRecordSteamInstant);
    }

    /**
     * 批量删除蒸汽历史数据
     *
     * @param objIds 需要删除的蒸汽历史数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordSteamInstantByObjIds(Long[] objIds) {
        return emsRecordSteamInstantMapper.deleteEmsRecordSteamInstantByObjIds(objIds);
    }

    /**
     * 删除蒸汽历史数据信息
     *
     * @param objId 蒸汽历史数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsRecordSteamInstantByObjId(Long objId) {
        return emsRecordSteamInstantMapper.deleteEmsRecordSteamInstantByObjId(objId);
    }


    /**
     * 查询蒸汽实时最后一条数据列表
     *
     * @param emsRecordSteamInstant 蒸汽历史数据
     * @return 蒸汽实时数据
     */
    @Override
    public List<EmsRecordSteamInstant> selectEmsRecordLatestSteamInstantList(EmsRecordSteamInstant emsRecordSteamInstant){
/*        return emsRecordSteamInstantMapper.selectEmsRecordLatestSteamInstantList(emsRecordSteamInstant);*/
        //只返回第一条数据,subList从索引0开始，只截取1条
        return emsRecordSteamInstantMapper.selectEmsRecordLatestSteamInstantList(emsRecordSteamInstant).subList(0,1);
    }

}
